@@ -33,6 +33,7 @@
 
 static GtkStatusIcon *statusicon = NULL;
 static char *icon_name = NULL;
+static char *tooltip = NULL;
 static NotifyNotification *notify = NULL;
 
 static void notify_action(NotifyNotification *notify,
@@ -40,6 +41,21 @@ static void notify_action(NotifyNotification *notify,
 {
 }
 
+gboolean notification_supports_actions (void)
+{
+	gboolean supports_actions = FALSE;
+	GList *caps = NULL;
+
+	caps = notify_get_server_caps ();
+	if (g_list_find_custom(caps, "actions", (GCompareFunc)g_strcmp0) != NULL)
+		supports_actions = TRUE;
+
+	g_list_foreach(caps, (GFunc)g_free, NULL);
+	g_list_free (caps);
+
+	return supports_actions;
+}
+
 void show_notification(const gchar *summary, const gchar *message,
 			const gchar *action, gint timeout, GCallback handler)
 {
@@ -95,8 +111,7 @@ GtkStatusIcon *init_notification(void)
 	notify_init("bluetooth-manager");
 
 	statusicon = gtk_status_icon_new_from_icon_name(icon_name);
-
-	gtk_status_icon_set_tooltip_markup(statusicon, _("Bluetooth Manager"));
+	gtk_status_icon_set_tooltip_markup(statusicon, tooltip);
 
 	return statusicon;
 }
@@ -109,6 +124,8 @@ void cleanup_notification(void)
 
 	g_free (icon_name);
 	icon_name = NULL;
+	g_free (tooltip);
+	tooltip = NULL;
 
 	notify_uninit();
 }
@@ -128,12 +145,15 @@ void hide_icon(void)
 void set_icon(gboolean enabled)
 {
 	const char *name = (enabled ? "bluetooth" : "bluetooth-disabled");
+	const char *_tooltip = enabled ? _("Bluetooth: Enabled") : _("Bluetooth: Disabled");
 
 	if (statusicon == NULL) {
 		g_free (icon_name);
 		icon_name = g_strdup (name);
+		tooltip = g_strdup (_tooltip);
 	} else {
 		gtk_status_icon_set_from_icon_name (statusicon, name);
+		gtk_status_icon_set_tooltip_markup(statusicon, _tooltip);
 	}
 }
 
